import socket

def send_sgd_command(ip, port, command):
    try:
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
            s.connect((ip, port))
            s.sendall(command.encode())
            s.shutdown(socket.SHUT_WR)
            print(f"Command sent: {command}")
    except Exception as e:
        print(f"Error sending command: {e}")

# Replace with your printer's current IP address
printer_ip = "192.168.1.29"  
printer_port = 9100

# Replace with your desired static IP, subnet mask, and gateway
new_ip = "192.168.1.29"
subnet_mask = "255.255.255.0"
gateway = "192.168.1.1"

# SGD commands to set IP, subnet, gateway, and HTTP port
commands = [
    f"! U1 setvar \"ip.addr\" \"{new_ip}\"\r\n",
    f"! U1 setvar \"ip.mask\" \"{subnet_mask}\"\r\n",
    f"! U1 setvar \"ip.gateway\" \"{gateway}\"\r\n",
    "! U1 setvar \"ip.port\" \"80\"\r\n",
    "! U1 setvar \"web.enable\" \"true\"\r\n"
]

# Sending commands
for cmd in commands:
    send_sgd_command(printer_ip, printer_port, cmd)



"""
  Tools to manage a zebra printer fleet and expose an API for routing print requests.
"""

import socket

class ZebraPrinter:

    def __init__(self, ip_address, port=9100, buffer_size=1024):
        self.ip_address = ip_address
        self.port = port
        self.buffer_size = buffer_size

        
    def send_command(self, command):
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
            s.connect((self.ip_address, self.port))
            s.sendall(command.encode())
            response = s.recv(self.buffer_size)
        return response.decode()

    
    def get_configuration(self):
        """Retrieve printer configuration using ^HH command"""
        return self.send_command("^XA^HH^XZ")

    
    def set_configuration(self, config):
        """
        Set printer configuration. 
        The `config` parameter should contain the necessary ZPL commands to adjust the configuration.
        After sending the configuration commands, the ^JUS command saves the configuration.
        """
        self.send_command(config)
        return self.send_command("^XA^JUS^XZ")



import socket
import sys

printer_ip = sys.argv[1]

def send_sgd_command(ip, port, command):
    try:
        # Creating a socket object
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
            s.connect((ip, port))
            s.sendall(command.encode())
            s.shutdown(socket.SHUT_WR)
            print(f"Command sent: {command}")
    except Exception as e:
        print(f"Error sending command: {e}")

# Printer IP and port (usually 9100 for Zebra printers)

printer_port = 9100

# SGD commands to set display.root_wml to default and delete WMINDEX.WML
commands = [
    "! U1 setvar \"device.restore_defaults\" \"factory\"\r\n",
    "! U1 setvar \"web.enable\" \"true\"\r\n",
    "! U1 setvar \"ip.port\" \"80\"\r\n"
]

# Sending commands
for cmd in commands:
    send_sgd_command(printer_ip, printer_port, cmd)



import sys
import zebra_day.print_mgr as zdpm


def generate_coarse_grid(x_dim, y_dim):
    step = 50
    zpl_strings = []
    for x in range(0, x_dim, step):
        for y in range(0, y_dim, step):
            zpl_strings.append(f"^FO{x},{y}^A0N,18,18^FD{x}^FS^FO{x},{y+20}^A0N,18,18^FD{y}^FS")
            #zpl_strings.append(f"^FO{x},{y}^A0N,22,22^FD{x},{y}^FS")
    return "^XA" + "".join(zpl_strings) + "^XZ"

def generate_fine_grid(top_left, bottom_right, step=20, expand=50):
    x_start = max(0, top_left[0] - expand)
    y_start = max(0, top_left[1] - expand)
    x_end = bottom_right[0] + expand
    y_end = bottom_right[1] + expand
    zpl_strings = []
    for x in range(x_start, x_end, step):
        for y in range(y_start, y_end, step):
            zpl_strings.append(f"^FO{x},{y}^A0N,20,20^FD{x},{y}^FS")
    return "^XA" + "".join(zpl_strings) + "^XZ"

def main(ip):

    zpld = zdpm.zpl()

    # Part 1: Coarse Grid
    x_dim = int(input("Enter width of the rectangle in dots: "))
    y_dim = int(input("Enter height of the rectangle in dots: "))
    print("\nZPL for coarse grid:\n")
    zpl_string = generate_coarse_grid(x_dim, y_dim)
    print(zpl_string)
    zpld.print_raw_zpl(zpl_string , ip)

    fh = open('./test_800dX800dCoordinateArray.zpl','w')
    fh.write(zpl_string)
    fh.close()
    
    # Part 2: Fine Grid
    #top_left = tuple(map(int, input("\nEnter top-left corner coordinates (x,y) separated by a comma: ").split(',')))
    #bottom_right = tuple(map(int, input("Enter bottom-right corner coordinates (x,y) separated by a comma: ").split(',')))
    #print("\nZPL for fine grid:\n")
    #zpl_string2 = generate_fine_grid(top_left, bottom_right)
    #zpld.print_raw_zpl(zpl_string2 , ip)
    
if __name__ == "__main__":

    main(sys.argv[1])



import socket
import sys

def send_zpl_to_printer(ip_address, port, zpl_string):
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
        s.connect((ip_address, port))
        s.sendall(zpl_string.encode())
        response = s.recv(1024)
    return response.decode()

# Example usage
ip = sys.argv[1]
zpl_command = '^XA^HH^XZ'  # This command retrieves the printer's configuration. Replace as needed.
response = send_zpl_to_printer(ip, 9100, zpl_command)
print(response)



import sys
import zebra_day.print_mgr as zdpm

class ZPLBoundaryTester:
    def __init__(self):
        # Starting coordinates
        self.x = 235
        self.y = 20  ##235,20
        
        # Step size (how much we move the print position each time)
        # Adjust based on the printer's resolution (DPI) and desired granularity.
        self.step = 100

        # Flags
        self.first_print_x = True
        self.first_print_y = True

        self.first_x = None
        self.first_y = None
        self.first_last_x = None
        self.first_last_y = None
        
    def generate_zpl(self):
        #zpl_string = f"^XA^FO{self.x},{self.y}^ADN,30,20^FDXXX^FS^XZ"
        zpl_string = f"^XA^FO{self.x},{self.y}^BY1^B3N,N,40,N,N^FDX^FS^XZ"
        #zpl_string = f"^XA^FO{self.x},{self.y}^A0N,100,100^FDX^FS^XZ"
        return zpl_string

    def process_feedback(self, feedback):
        if feedback == "n":  # not yet
            if not self.first_print_y:
                print("Testing completed.")
                return None
            self.y += self.step
            self.x += self.step
            self.first_print_x = True
            return self.generate_zpl()

        elif feedback == "b":  # begins
            self.first_print_x = False
            self.x += self.step
            return self.generate_zpl()

        elif feedback == "c":  # continuses
            self.x += self.step
            return self.generate_zpl()

        elif feedback == "o":  # off
            if self.first_print_x:
                self.first_print_y = False
            else:
                self.y += self.step
                self.x = 0
                self.first_print_x = True
            return self.generate_zpl()

        else:
            print("Invalid feedback. Please provide a valid feedback string.")
            return None

def main(ip='localhost'):
    tester = ZPLBoundaryTester()
    zpl_string = tester.generate_zpl()

    zpld = zdpm.zpl()
    
    while zpl_string:
        print(f"Send the following ZPL to the printer:\n{zpl_string}")
        feedback = input("Please provide your feedback: ")
        zpl_string = tester.process_feedback(feedback)
        zpld.print_raw_zpl(zpl_string , ip)

if __name__ == "__main__":
    ip = sys.argv[1]
    main(ip)



import sys
import socket

def send_sgd_query(ip, port, command):
    response = ""
    try:
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
            s.connect((ip, port))
            s.sendall(command.encode())
            s.shutdown(socket.SHUT_WR)
            while True:
                data = s.recv(1024)
                if not data:
                    break
                response += data.decode()
    except Exception as e:
        print(f"Error sending command: {e}")
    return response.strip()

# Replace with your printer's IP address
printer_ip = sys.argv[1]
printer_port = 9100

# SGD commands to get IP and HTTP port
ip_command = "! U1 getvar \"ip.addr\"\r\n"
port_command = "! U1 getvar \"ip.port\"\r\n"

# Sending commands and receiving responses
ip_address = send_sgd_query(printer_ip, printer_port, ip_command)
http_port = send_sgd_query(printer_ip, printer_port, port_command)

print(f"Printer IP Address: {ip_address}")
print(f"HTTP Port: {http_port}")
